# Examples

This folder contains actively maintained examples of use of unitorch organized by ML task.

# The Big Table of Tasks

Here is the list of all examples for both command line and library use. The links to Colab notebooks to walk through the scripts and run them easily.

| Task           | Dataset | Model                 | Command Line                               | Colab                                                                                                                                                                                         |
| -------------- | ------- | --------------------- | ------------------------------------------ | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Classification |         | BertForClassification | unitorch-train hub/classification/bert.ini | [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fuliucansheng/unitorch/blob/master/notebooks/classification/bert.ipynb) |
| Classification |         | ClipForClassification | unitorch-train hub/classification/bert.ini | [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fuliucansheng/unitorch/blob/master/notebooks/classification/clip.ipynb) |
| Generation     |         | BartForGeneration     | unitorch-train hub/generation/bart.ini     | [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fuliucansheng/unitorch/blob/master/notebooks/generation/bart.ipynb)     |
| Generation     |         | XPegasusForGeneration | unitorch-train hub/generation/xpegasus.ini | [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fuliucansheng/unitorch/blob/master/notebooks/generation/xpegasus.ipynb) |
| Caption        |         | BlipForImageCaption   | unitorch-train hub/caption/blip.ini        | [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/fuliucansheng/unitorch/blob/master/notebooks/caption/blip.ipynb)        |
